==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Quota</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Impostazioni predefinite quota</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Impostazioni quota</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Predefiniti per nuovi disegni</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Scientific</source>
        <translation>Scientifica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Decimale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Ingegneristica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architettonica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Frazionale</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Decimal Degrees</source>
        <translation>Gradi Decimali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Grad/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Centesimali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radianti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Unità topografiche</translation>
    </message>
    <message>
        <location line="+138"/>
        <source>Unit / Format</source>
        <translation>Unità / formato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>L&apos;unità di disegno deve essere &apos;Inch&apos; per visualizzare le etichette in formati di dimensione &apos;architettonica&apos; o &apos;Engineering&apos;. Formato cambiato in &apos;decimale&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Misure</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Altezza Testo:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Offset della linea di estensione:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Estensione della linea di estensione:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Distanza del testo dalla linea:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Dimensione Freccia:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Fattore di Scala:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Stile freccia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architettonica Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Label Format</source>
        <translation>Formato etichetta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Quota Lineare</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;Precisione:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Mostra zeri finali</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Quota angolare</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;Precisione:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Edit/DrawingPreferences/DimensionSettings/ts/DimensionSettings_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>DimensionSettings</name>
    <message>
        <location filename="../DimensionSettings.js" line="+29"/>
        <source>Dimension</source>
        <translation>Quota</translation>
    </message>
    <message>
        <source>Default Dimension Settings</source>
        <translation type="obsolete">Impostazioni predefinite quota</translation>
    </message>
    <message>
        <location line="-2"/>
        <location line="+2"/>
        <source>Dimension Settings</source>
        <translation>Impostazioni quota</translation>
    </message>
    <message>
        <location line="-2"/>
        <source>Defaults for New Drawings</source>
        <translation>Predefiniti per nuovi disegni</translation>
    </message>
    <message>
        <location line="+109"/>
        <source>Scientific</source>
        <translation>Scientifica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal</source>
        <translation>Decimale</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Engineering</source>
        <translation>Ingegneristica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectural</source>
        <translation>Architettonica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fractional</source>
        <translation>Frazionale</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Decimal Degrees</source>
        <translation>Gradi Decimali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Deg/min/sec</source>
        <translation>Grad/min/sec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gradians</source>
        <translation>Centesimali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Radians</source>
        <translation>Radianti</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Surveyor&apos;s units</source>
        <translation>Unità topografiche</translation>
    </message>
    <message>
        <location line="+193"/>
        <source>Unit / Format</source>
        <translation>Unità / formato</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The drawing unit must be &apos;Inch&apos; or &apos;Foot&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation>L&apos;unità di disegno deve essere &apos;Inch&apos; o &apos;Foot&apos; per visualizzare le etichette in formati di dimensione &apos;architettonica&apos; o &apos;Engineering&apos;. Formato cambiato in &apos;decimale&apos;.</translation>
    </message>
    <message>
        <source>The drawing unit must be &apos;Inch&apos; to display dimension labels in formats &apos;Architectural&apos; or &apos;Engineering&apos;. Format changed to &apos;Decimal&apos;.</source>
        <translation type="vanished">L&apos;unità di disegno deve essere &apos;Inch&apos; per visualizzare le etichette in formati di dimensione &apos;architettonica&apos; o &apos;Engineering&apos;. Formato cambiato in &apos;decimale&apos;.</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+29"/>
        <source>Sizes</source>
        <translation>Misure</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Keep proportions</source>
        <translation>Mantiene proporzioni</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Text height:</source>
        <translation>Altezza Testo:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line offset:</source>
        <translation>Offset della linea di estensione:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Extension line extension:</source>
        <translation>Estensione della linea di estensione:</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Dimension line gap:</source>
        <translation>Distanza del testo dalla linea:</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Arrow size:</source>
        <translation>Dimensione Freccia:</translation>
    </message>
    <message>
        <location line="+95"/>
        <source>Size scale factor:</source>
        <translation>Fattore di Scala:</translation>
    </message>
    <message>
        <location line="+38"/>
        <source>Arrow Style</source>
        <translation>Stile freccia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Arrow</source>
        <translation>Freccia</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Architectural Tick</source>
        <translation>Architettonica Tick</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Font</source>
        <translation>Carattere</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Dimension label font:</source>
        <translation>Carattere:</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Label Format</source>
        <translation>Formato etichetta</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Linear Dimensions</source>
        <translation>Quota Lineare</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>&amp;Format:</source>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>P&amp;recision:</source>
        <translation>&amp;Precisione:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+60"/>
        <source>Show trailing zeros</source>
        <translation>Mostra zeri finali</translation>
    </message>
    <message>
        <location line="-50"/>
        <source>Angular Dimensions</source>
        <translation>Quota angolare</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>F&amp;ormat:</source>
        <translation>&amp;Formato:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Pre&amp;cision:</source>
        <translation>&amp;Precisione:</translation>
    </message>
    <message>
        <location line="+32"/>
        <location line="+19"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
</context>
</TS>
